"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
// tslint:disable: max-classes-per-file
var React = require("react");
var renderer = require("react-test-renderer");
var index_1 = require("./index");
describe("error when loading langauge", function () {
    var MyComponent = /** @class */ (function (_super) {
        tslib_1.__extends(MyComponent, _super);
        function MyComponent() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        // tslint:disable-next-line prefer-function-over-method
        MyComponent.prototype.render = function () {
            return false;
        };
        // tslint:disable-next-line prefer-function-over-method
        MyComponent.prototype.getTranslation = function () {
            return tslib_1.__awaiter(this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    throw new Error("test error");
                });
            });
        };
        return MyComponent;
    }(index_1.JedPureComponent));
    it("throws promise error if callback provided", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var languageLoadedPromise;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    languageLoadedPromise = new Promise(function (resolve, reject) {
                        renderer.create(React.createElement(MyComponent, { languageCode: "yy", languageLoadedCallback: function (e, render) { return (e === undefined ? resolve(render) : reject(e)); } }));
                    });
                    return [4 /*yield*/, expect(languageLoadedPromise).rejects.toEqual(new Error("test error"))];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it("invoke `console.warn` if callback not provided", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var originalWarn, warnPromise;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    originalWarn = console.warn;
                    warnPromise = new Promise(function (resolve) {
                        console.warn = resolve;
                    });
                    renderer.create(React.createElement(MyComponent, { languageCode: "yy" })).toJSON();
                    return [4 /*yield*/, expect(warnPromise).resolves.toEqual(new Error("test error"))];
                case 1:
                    _a.sent();
                    console.warn = originalWarn;
                    return [2 /*return*/];
            }
        });
    }); });
});
describe("getTranslation returns empty objects", function () {
    var MyComponent = /** @class */ (function (_super) {
        tslib_1.__extends(MyComponent, _super);
        function MyComponent() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        MyComponent.prototype.render = function () {
            return React.createElement("span", null, this._("Hello world"));
        };
        // tslint:disable-next-line prefer-function-over-method
        MyComponent.prototype.getTranslation = function () {
            return tslib_1.__awaiter(this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    return [2 /*return*/, {}];
                });
            });
        };
        return MyComponent;
    }(index_1.JedPureComponent));
    it("renders immediately and after waiting for language resolve", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var component, languageLoadedPromise, mockCallback;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    languageLoadedPromise = new Promise(function (resolve, reject) {
                        component = renderer.create(React.createElement(MyComponent, { languageCode: "yy", languageLoadedCallback: function (e, render) { return e === undefined ? resolve(render) : reject(e); } }));
                    });
                    // tslint:disable-next-line no-non-null-assertion no-unnecessary-type-assertion
                    component = component;
                    mockCallback = jest.fn();
                    component.getInstance().componentDidUpdate = mockCallback;
                    expect(component.toJSON()).toMatchSnapshot();
                    return [4 /*yield*/, expect(languageLoadedPromise).resolves.toEqual(true)];
                case 1:
                    _a.sent();
                    expect(mockCallback.mock.calls.length).toBe(1);
                    expect(component.toJSON()).toMatchSnapshot();
                    return [2 /*return*/];
            }
        });
    }); });
});
describe("getTranslation returns jed objects", function () {
    var MyComponent = /** @class */ (function (_super) {
        tslib_1.__extends(MyComponent, _super);
        function MyComponent() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        MyComponent.prototype.render = function () {
            var k = ["%s dog", "%s dogs"];
            var n1 = index_1.sprintf(this.ngettext(k[0], k[1], 1), 1);
            var n2 = index_1.sprintf(this.ngettext(k[0], k[1], 2), 2);
            return React.createElement("span", null,
                n1,
                ", ",
                n2);
        };
        // tslint:disable-next-line prefer-function-over-method
        MyComponent.prototype.getTranslation = function () {
            return tslib_1.__awaiter(this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    return [2 /*return*/, {
                            locale_data: {
                                messages: {
                                    "": {
                                        lang: "yy",
                                    },
                                    "%s dog": ["%s hunden", "%s hundra"],
                                },
                            },
                        }];
                });
            });
        };
        return MyComponent;
    }(index_1.JedPureComponent));
    it("renders default language, then translated language, with callback", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var component, languageLoadedPromise, mockCallback;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    languageLoadedPromise = new Promise(function (resolve, reject) {
                        component = renderer.create(React.createElement(MyComponent, { languageCode: "yy", languageLoadedCallback: function (e, render) { return (e === undefined ? resolve(render) : reject(e)); } }));
                    });
                    // tslint:disable-next-line no-non-null-assertion no-unnecessary-type-assertion
                    component = component;
                    mockCallback = jest.fn();
                    component.getInstance().componentDidUpdate = mockCallback;
                    expect(component.toJSON()).toMatchSnapshot();
                    return [4 /*yield*/, expect(languageLoadedPromise).resolves.toEqual(true)];
                case 1:
                    _a.sent();
                    expect(mockCallback.mock.calls.length).toBe(1);
                    expect(component.toJSON()).toMatchSnapshot();
                    return [2 /*return*/];
            }
        });
    }); });
    it("renders default language, then translated language, without callback", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var component, componentUpdatePromise;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    component = renderer.create(React.createElement(MyComponent, { languageCode: "yy" }));
                    componentUpdatePromise = new Promise(function (resolve) {
                        component.getInstance().componentDidUpdate = resolve;
                    });
                    expect(component.toJSON()).toMatchSnapshot();
                    return [4 /*yield*/, expect(componentUpdatePromise).resolves.toEqual({ languageCode: "yy" })];
                case 1:
                    _a.sent();
                    expect(component.toJSON()).toMatchSnapshot();
                    return [2 /*return*/];
            }
        });
    }); });
});
describe("getTranslation returns undefined", function () {
    var MyComponent = /** @class */ (function (_super) {
        tslib_1.__extends(MyComponent, _super);
        function MyComponent() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        MyComponent.prototype.render = function () {
            return React.createElement("span", null, this._("Hello world"));
        };
        // tslint:disable-next-line prefer-function-over-method
        MyComponent.prototype.getTranslation = function () {
            return tslib_1.__awaiter(this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    return [2 /*return*/];
                });
            });
        };
        return MyComponent;
    }(index_1.JedPureComponent));
    it("renders immediately and does not render again", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var component, languageLoadedPromise, mockCallback;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    languageLoadedPromise = new Promise(function (resolve, reject) {
                        component = renderer.create(React.createElement(MyComponent, { languageCode: "yy", languageLoadedCallback: function (e, render) { return (e === undefined ? resolve(render) : reject(e)); } }));
                    });
                    // tslint:disable-next-line no-non-null-assertion no-unnecessary-type-assertion
                    component = component;
                    mockCallback = jest.fn();
                    component.getInstance().componentDidUpdate = mockCallback;
                    expect(component.toJSON()).toMatchSnapshot();
                    return [4 /*yield*/, expect(languageLoadedPromise).resolves.toEqual(false)];
                case 1:
                    _a.sent();
                    expect(mockCallback.mock.calls.length).toBe(0);
                    expect(component.toJSON()).toMatchSnapshot();
                    return [2 /*return*/];
            }
        });
    }); });
});
